@@ -235,6 +235,13 @@ class AwsClustersAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import gke_multicloud_v1
 
             async def sample_create_aws_cluster():
@@ -244,11 +251,11 @@ class AwsClustersAsyncClient:
                 # Initialize request argument(s)
                 aws_cluster = gke_multicloud_v1.AwsCluster()
                 aws_cluster.networking.vpc_id = "vpc_id_value"
-                aws_cluster.networking.pod_address_cidr_blocks = ['pod_address_cidr_blocks_value_1', 'pod_address_cidr_blocks_value_2']
-                aws_cluster.networking.service_address_cidr_blocks = ['service_address_cidr_blocks_value_1', 'service_address_cidr_blocks_value_2']
+                aws_cluster.networking.pod_address_cidr_blocks = ['pod_address_cidr_blocks_value1', 'pod_address_cidr_blocks_value2']
+                aws_cluster.networking.service_address_cidr_blocks = ['service_address_cidr_blocks_value1', 'service_address_cidr_blocks_value2']
                 aws_cluster.aws_region = "aws_region_value"
                 aws_cluster.control_plane.version = "version_value"
-                aws_cluster.control_plane.subnet_ids = ['subnet_ids_value_1', 'subnet_ids_value_2']
+                aws_cluster.control_plane.subnet_ids = ['subnet_ids_value1', 'subnet_ids_value2']
                 aws_cluster.control_plane.iam_instance_profile = "iam_instance_profile_value"
                 aws_cluster.control_plane.database_encryption.kms_key_arn = "kms_key_arn_value"
                 aws_cluster.control_plane.aws_services_authentication.role_arn = "role_arn_value"
@@ -397,6 +404,13 @@ class AwsClustersAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import gke_multicloud_v1
 
             async def sample_update_aws_cluster():
@@ -406,11 +420,11 @@ class AwsClustersAsyncClient:
                 # Initialize request argument(s)
                 aws_cluster = gke_multicloud_v1.AwsCluster()
                 aws_cluster.networking.vpc_id = "vpc_id_value"
-                aws_cluster.networking.pod_address_cidr_blocks = ['pod_address_cidr_blocks_value_1', 'pod_address_cidr_blocks_value_2']
-                aws_cluster.networking.service_address_cidr_blocks = ['service_address_cidr_blocks_value_1', 'service_address_cidr_blocks_value_2']
+                aws_cluster.networking.pod_address_cidr_blocks = ['pod_address_cidr_blocks_value1', 'pod_address_cidr_blocks_value2']
+                aws_cluster.networking.service_address_cidr_blocks = ['service_address_cidr_blocks_value1', 'service_address_cidr_blocks_value2']
                 aws_cluster.aws_region = "aws_region_value"
                 aws_cluster.control_plane.version = "version_value"
-                aws_cluster.control_plane.subnet_ids = ['subnet_ids_value_1', 'subnet_ids_value_2']
+                aws_cluster.control_plane.subnet_ids = ['subnet_ids_value1', 'subnet_ids_value2']
                 aws_cluster.control_plane.iam_instance_profile = "iam_instance_profile_value"
                 aws_cluster.control_plane.database_encryption.kms_key_arn = "kms_key_arn_value"
                 aws_cluster.control_plane.aws_services_authentication.role_arn = "role_arn_value"
@@ -556,6 +570,13 @@ class AwsClustersAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import gke_multicloud_v1
 
             async def sample_get_aws_cluster():
@@ -667,6 +688,13 @@ class AwsClustersAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import gke_multicloud_v1
 
             async def sample_list_aws_clusters():
@@ -801,6 +829,13 @@ class AwsClustersAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import gke_multicloud_v1
 
             async def sample_delete_aws_cluster():
@@ -862,9 +897,6 @@ class AwsClustersAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -929,6 +961,13 @@ class AwsClustersAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import gke_multicloud_v1
 
             async def sample_generate_aws_access_token():
@@ -1023,6 +1062,13 @@ class AwsClustersAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import gke_multicloud_v1
 
             async def sample_create_aws_node_pool():
@@ -1181,6 +1227,13 @@ class AwsClustersAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import gke_multicloud_v1
 
             async def sample_update_aws_node_pool():
@@ -1332,6 +1385,13 @@ class AwsClustersAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import gke_multicloud_v1
 
             async def sample_get_aws_node_pool():
@@ -1445,6 +1505,13 @@ class AwsClustersAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import gke_multicloud_v1
 
             async def sample_list_aws_node_pools():
@@ -1577,6 +1644,13 @@ class AwsClustersAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import gke_multicloud_v1
 
             async def sample_delete_aws_node_pool():
@@ -1638,9 +1712,6 @@ class AwsClustersAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -1707,6 +1778,13 @@ class AwsClustersAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import gke_multicloud_v1
 
             async def sample_get_aws_server_config():
