@@ -19,15 +19,20 @@ from typing import Dict, Type
 from .base import AwsClustersTransport
 from .grpc import AwsClustersGrpcTransport
 from .grpc_asyncio import AwsClustersGrpcAsyncIOTransport
+from .rest import AwsClustersRestTransport
+from .rest import AwsClustersRestInterceptor
 
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[AwsClustersTransport]]
 _transport_registry["grpc"] = AwsClustersGrpcTransport
 _transport_registry["grpc_asyncio"] = AwsClustersGrpcAsyncIOTransport
+_transport_registry["rest"] = AwsClustersRestTransport
 
 __all__ = (
     "AwsClustersTransport",
     "AwsClustersGrpcTransport",
     "AwsClustersGrpcAsyncIOTransport",
+    "AwsClustersRestTransport",
+    "AwsClustersRestInterceptor",
 )
